@@ -173,6 +173,7 @@
 #define SYSDB_SUBDOMAIN_ENUM "enumerate"
 #define SYSDB_SUBDOMAIN_FOREST "memberOfForest"
 #define SYSDB_SUBDOMAIN_TRUST_DIRECTION "trustDirection"
+#define SYSDB_SUBDOMAIN_TRUST_TYPE "trustType"
 #define SYSDB_UPN_SUFFIXES "upnSuffixes"
 #define SYSDB_SITE "site"
 #define SYSDB_ENABLED "enabled"
@@ -276,19 +277,44 @@
                         SYSDB_ORIG_DN, \
                         NULL}
 
-#define SYSDB_GRSRC_ATTRS {SYSDB_NAME, SYSDB_GIDNUM, \
-                           SYSDB_MEMBERUID, \
-                           SYSDB_MEMBER, \
-                           SYSDB_GHOST, \
-                           SYSDB_DEFAULT_ATTRS, \
-                           SYSDB_SID_STR, \
-                           SYSDB_OVERRIDE_DN, \
-                           SYSDB_OVERRIDE_OBJECT_DN, \
-                           SYSDB_DEFAULT_OVERRIDE_NAME, \
-                           SYSDB_UUID, \
-                           ORIGINALAD_PREFIX SYSDB_NAME, \
-                           ORIGINALAD_PREFIX SYSDB_GIDNUM, \
-                           NULL}
+/* Strictly speaking it should return 'const char * const *' but
+ * that gets really unreadable.
+ */
+__attribute__((always_inline))
+static inline const char **SYSDB_GRSRC_ATTRS(const struct sss_domain_info *domain)
+{
+    static const char * __SYSDB_GRSRC_ATTRS_NO_MEMBERS[] = {
+        SYSDB_NAME, SYSDB_GIDNUM,
+        SYSDB_DEFAULT_ATTRS,
+        SYSDB_SID_STR,
+        SYSDB_OVERRIDE_DN,
+        SYSDB_OVERRIDE_OBJECT_DN,
+        SYSDB_DEFAULT_OVERRIDE_NAME,
+        SYSDB_UUID,
+        NULL
+    };
+    static const char * __SYSDB_GRSRC_ATTRS_WITH_MEMBERS[] = {
+        SYSDB_NAME, SYSDB_GIDNUM,
+        SYSDB_MEMBERUID,
+        SYSDB_MEMBER,
+        SYSDB_GHOST,
+        SYSDB_DEFAULT_ATTRS,
+        SYSDB_SID_STR,
+        SYSDB_OVERRIDE_DN,
+        SYSDB_OVERRIDE_OBJECT_DN,
+        SYSDB_DEFAULT_OVERRIDE_NAME,
+        SYSDB_UUID,
+        ORIGINALAD_PREFIX SYSDB_NAME,
+        ORIGINALAD_PREFIX SYSDB_GIDNUM,
+        NULL
+    };
+
+    if (domain && domain->ignore_group_members) {
+        return __SYSDB_GRSRC_ATTRS_NO_MEMBERS;
+    } else {
+        return __SYSDB_GRSRC_ATTRS_WITH_MEMBERS;
+    }
+}
 
 #define SYSDB_NETGR_ATTRS {SYSDB_NAME, SYSDB_NETGROUP_TRIPLE, \
                            SYSDB_NETGROUP_MEMBER, \
@@ -566,6 +592,7 @@ errno_t sysdb_subdomain_store(struct sysdb_ctx *sysdb,
                               enum sss_domain_mpg_mode mpg_mode,
                               bool enumerate, const char *forest,
                               uint32_t trust_direction,
+                              uint32_t trust_type,
                               struct ldb_message_element *upn_suffixes);
 
 errno_t sysdb_update_subdomains(struct sss_domain_info *domain,
@@ -607,6 +634,7 @@ struct sss_domain_info *new_subdomain(TALLOC_CTX *mem_ctx,
                                       const char *forest,
                                       const char **upn_suffixes,
                                       uint32_t trust_direction,
+                                      uint32_t trust_type,
                                       struct confdb_ctx *confdb,
                                       bool enabled);
 
@@ -731,8 +759,7 @@ errno_t sysdb_add_overrides_to_object(struct sss_domain_info *domain,
                                       const char **req_attrs);
 
 errno_t sysdb_add_group_member_overrides(struct sss_domain_info *domain,
-                                         struct ldb_message *obj,
-                                         bool expect_override_dn);
+                                         struct ldb_message *obj);
 
 errno_t sysdb_getpwnam_with_views(TALLOC_CTX *mem_ctx,
                                   struct sss_domain_info *domain,
@@ -1566,11 +1593,6 @@ errno_t sysdb_get_sids_of_members(TALLOC_CTX *mem_ctx,
                                   const char ***_dns,
                                   size_t *_n);
 
-errno_t sysdb_get_user_members_recursively(TALLOC_CTX *mem_ctx,
-                                           struct sss_domain_info *dom,
-                                           struct ldb_dn *group_dn,
-                                           struct ldb_result **members);
-
 errno_t sysdb_handle_original_uuid(const char *orig_name,
                                    struct sysdb_attrs *src_attrs,
                                    const char *src_name,
